tind and Other Time Index RepresentationsBesides Date, POSIXct, and POSIXlt classes from
package base, tind currently supports conversion between
tind and the following classes: yearmon, yearqtr
(both from package zoo), timeDate (from package timeDate),
chron, dates, times (from package chron),
IDate, ITime (from package data.table),
and hms (from package hms).
# S3 method for yearmon
as.tind(x, ...)as.yearmon(x, ...)
# S3 method for yearqtr
as.tind(x, ...)
as.yearqtr(x, ...)
# S3 method for timeDate
as.tind(x, digits = 0L, ...)
as.timeDate(x, ...)
# S3 method for chron
as.tind(x, digits = 0L, ...)
as.chron(x, ...)
# S3 method for dates
as.tind(x, ...)
as.dates(x, ...)
# S3 method for times
as.tind(x, digits = 0L, ...)
as.times(x)
# S3 method for IDate
as.tind(x, ...)
as.IDate(x, ...)
# S3 method for ITime
as.tind(x, ...)
as.ITime(x)
# S3 method for hms
as.tind(x, ...)
as_hms(x)
as.xxx returns an object of xxx class of the same
length as the argument.
an R object to be converted.
(ignored) further arguments passed to or from other methods.
an integer value (0--6) determining the number of decimal places for seconds to be preserved during conversion (0 by default).
Date-time indices resulting from conversion of chron objects
always have time zone set to UTC. Use tzone<-
or as.tzone methods when necessary.
as.tind and tind-coercion for conversions
to and from tind, date2num and num2date
for conversion between tind and integer representations of dates
(days since ...) found in different software packages.